tipster
=======

Описание
--------
Модульная программа для сбора и отсылки системных метрик на удаленный сервер _statsd_ по UDP протоколу. 
Изначально она создавалась в рамках тестирования внутренней системы мониторинга "БАРС Груп", но в 
перспективе может быть расширена до вполне самостоятельного продукта.

Установка
---------

1. Поставить пакет, содержащий последнюю версию tipster:
> pip install tipster -i http://pypi.bars-open.ru/simple

2. Свежеустановленный пакет может быть запущен прямо из командной строки:
> bars@test-server:~$ tipster

Настройка
---------

Опции командной строки:
 
 - **_-d_** - просто выводить собранные метрики на экран, вместо отсылки их к statsd;
 - **_-c "имя файла"_** - загрузить настройки из указанного YAML-файла.

Основные настройки прописываются в файле конфигурации, который представляет из себя словарь
в формате [YAML]. 

На данный момент существует две секции настроек:

- _identity_ - идентифицирующая информация, с помощью которой формируется
префикс отсылаемых метрик. 
- _statsd_ - имя хоста и порт сервера _statsd_.

Идентифицирующая информация состоит из следующих полей:

- **region** - код региона, в котором установлен сервер (примеры: _tatar_, _kchr_, _msk_);
- **client** - клиент, который обслуживается данным сервером (примеры: _bars_, _atk_, _minobr_);
- **product** - продукт, под который отведен данный сервер (примеры: _epk_, _webbb_, _kinder_);
- **instance** - необязательный параметр для указания конкретного экземпляра сервера, в случае сложного развертывания (пример: _test_, _node1_, _slave2_).

Параметры statsd состоят из следующих полей:

- **host** - адрес хоста, на котором развернут _statsd_ (по умолчанию: _localhost_);
- **port** - порт, который слушает _statsd_ (по умолчанию: 8125).

Пример файла конфигурации
-------------------------

<pre>
identity:
    client: c
    region: r
    product: p
    instance: i

statsd:
    host: 91.203.194.148
    port: 8125
</pre>

Принцип работы
--------------

- При запуске _tipster_ ищет все доступные для загрузки Python-файлы в папке _informers_;
- Каждый найденный файл будет запущен в отдельном подпроцессе через вызов метода _collect_;
- Метод collect каждый N секунд будет собирать данные о системе и передавать их основному процессу;
- Основной процесс предваряет имя каждой полученной метрики расчитанным префиксом с идентификаторами;
- Данные отсылаются _statsd_.

Формат кодированияи метрик описан в [Wiki].

Интервал сбора данных каждым модулем по умолчанию равен _15 секундам_, но может быть переопределен для
каждого отдельного модуля в файле конфигурации:

<pre>
cpu:
    interval: 60 # отсылать загруженность процессора каждую минуту (60 секунд)
    
io:
    interval: 30
</pre>

Существующие модули:

- **io** - статистика по количеству и скорости прочитанных/записанных данных с каждого устройства ввода/вывода;
- **cpu** - загруженность каждого из ядер процессора (всех ядер всех процессоров) в процентах;
- **net** - статистика переданных/полученных данных по каждому сетевому интерфейсу;
- **memory** - количество свободной физической и виртуальной памяти в байтах:
- **storage** - количество свободного места на каждом из подключенных разделов в байтах/процентах.

[YAML]: http://en.wikipedia.org/wiki/YAML "Yet Another Markup Language"
[Wiki]: https://31.13.131.67/projects/dev-py/wiki/Monitoring-send-format "Описание формата взамодействия"