#coding: utf-8

import hashlib
import psutil
import time

DEFAULT_INTERVAL = 15

def emit(channel, info):
    channel.put(info)


def hash_nic_name(s):
    md5 = hashlib.md5()
    md5.update(s)
    return md5.hexdigest()


def collect(feed, config=None):
    nic_ids = {}
    previous_read = {}
    previous_written = {}

    if not config:
        config = {}

    interval = config.get('interval', DEFAULT_INTERVAL)

    # Чтобы избежать _внезапных_ пиков при первом цикле сборки скоростей,
    # заранее заполняем массив актуальным количество считанных и записанных байт.
    initial_nic_op = psutil.net_io_counters(pernic=True)
    for nic, counters in initial_nic_op.iteritems():
        previous_read[nic] = counters.bytes_recv
        previous_written[nic] = counters.bytes_sent

    while True:
        per_nic_io = psutil.net_io_counters(pernic=True)

        for nic_id, counters in per_nic_io.iteritems():
            # Избегаем постоянного вычисления хэша для известных партиций
            nic_hash = nic_ids.setdefault(nic_id,
                                            'interface_{0}'.format(hash_nic_name(nic_id)))
            r1 = previous_read[nic_id]
            r2 = counters.bytes_recv
            received_per_sec = int((r2 - r1) / interval)

            r1 = previous_written[nic_id]
            r2 = counters.bytes_sent
            sent_per_sec = int((r2 - r1) / interval)

            emit(feed, ('{0}.net.recv.bytes_per_sec'.format(nic_hash), received_per_sec, 'gauge'))
            emit(feed, ('{0}.net.sent.bytes_per_sec'.format(nic_hash), sent_per_sec, 'gauge'))

            emit(feed, ('{0}.net.sent.bytes'.format(nic_hash), counters.bytes_sent, 'gauge'))
            emit(feed, ('{0}.net.recv.bytes'.format(nic_hash), counters.bytes_recv, 'gauge'))

            previous_read[nic_id] = counters.bytes_recv
            previous_written[nic_id] = counters.bytes_sent

        time.sleep(interval)
